Learn R Programming

ncpen (version 1.0.0)

coef.cv.ncpen: coef.cv.ncpen: extracts the optimal coefficients from cv.ncpen.

Description

The function returns the optimal vector of coefficients.

Usage

# S3 method for cv.ncpen
coef(object, type = c("rmse", "like"), ...)

Arguments

object

(cv.ncpen object) fitted cv.ncpen object.

type

(character) a cross-validated error type which is either rmse or like.

...

other S3 parameters. Not used. Each error type is defined in cv.ncpen.

Value

the optimal coefficients vector selected by cross-validation.

type

error type.

lambda

the optimal lambda selected by CV.

beta

the optimal coefficients selected by CV.

References

Lee, S., Kwon, S. and Kim, Y. (2016). A modified local quadratic approximation algorithm for penalized optimization problems. Computational Statistics and Data Analysis, 94, 275-286.

See Also

cv.ncpen, plot.cv.ncpen , gic.ncpen

Examples

Run this code
# NOT RUN {
### linear regression with scad penalty
sam =  sam.gen.ncpen(n=200,p=10,q=5,cf.min=0.5,cf.max=1,corr=0.5)
x.mat = sam$x.mat; y.vec = sam$y.vec
fit = cv.ncpen(y.vec=y.vec,x.mat=x.mat,n.lambda=10)
coef(fit)
### logistic regression with classo penalty
sam =  sam.gen.ncpen(n=200,p=10,q=5,cf.min=0.5,cf.max=1,corr=0.5,family="binomial")
x.mat = sam$x.mat; y.vec = sam$y.vec
fit = cv.ncpen(y.vec=y.vec,x.mat=x.mat,n.lambda=10,family="binomial",penalty="classo")
coef(fit)
### multinomial regression with sridge penalty
sam =  sam.gen.ncpen(n=200,p=10,q=5,k=3,cf.min=0.5,cf.max=1,corr=0.5,family="multinomial")
x.mat = sam$x.mat; y.vec = sam$y.vec
fit = cv.ncpen(y.vec=y.vec,x.mat=x.mat,n.lambda=10,family="multinomial",penalty="sridge")
coef(fit)
# }

Run the code above in your browser using DataLab